@@ -1,13 +1,14 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-03-22'; # DATE
-our $VERSION = '0.99'; # VERSION
+our $DATE = '2015-03-24'; # DATE
+our $VERSION = '1.00'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
 # use warnings; # already enabled by Mo
 use Log::Any::IfLOG '$log';
 
+use List::Util qw(first);
 use Mo qw(build default);
 #use Moo;
 extends 'Perinci::CmdLine::Base';
@@ -214,12 +215,11 @@ sub __gen_table {
             }
         }
         if ($tcos) {
-            use experimental 'smartmatch';
             # find an entry in tcos that @columns contains all the columns of
           COLS:
             for my $cols (@$tcos) {
-                for (@$cols) {
-                    next COLS unless $_ ~~ @columns;
+                for my $col (@$cols) {
+                    next COLS unless first {$_ eq $col} @columns;
                 }
                 $column_orders = $cols;
                 last SET_COLUMN_ORDERS;
@@ -506,7 +506,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.99 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-22.
+This document describes version 1.00 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-24.
 
 =head1 SYNOPSIS
 
@@ -716,7 +716,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
